summaryrefslogtreecommitdiff
path: root/src/lib/timer.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-12-13 10:06:18 +0000
committerCarl Hetherington <cth@carlh.net>2013-12-13 10:06:18 +0000
commit097a1fb413bbbb89182161d4c1a31daa5419ec96 (patch)
tree87d6ed5b14e7554b26f565380b69528ab3ec10ec /src/lib/timer.cc
parentea910e250a0fb3b0ad3ce0cf32dd27b24c17cd1d (diff)
Time -> DCPTime.
Diffstat (limited to 'src/lib/timer.cc')
-rw-r--r--src/lib/timer.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/lib/timer.cc b/src/lib/timer.cc
index 69a7e3aa9..a20a08b07 100644
--- a/src/lib/timer.cc
+++ b/src/lib/timer.cc
@@ -31,14 +31,14 @@
using namespace std;
/** @param n Name to use when giving output */
-PeriodTimer::PeriodTimer (string n)
+PeriodDCPTimer::PeriodDCPTimer (string n)
: _name (n)
{
gettimeofday (&_start, 0);
}
-/** Destroy PeriodTimer and output the time elapsed since its construction */
-PeriodTimer::~PeriodTimer ()
+/** Destroy PeriodDCPTimer and output the time elapsed since its construction */
+PeriodDCPTimer::~PeriodDCPTimer ()
{
struct timeval stop;
gettimeofday (&stop, 0);
@@ -48,7 +48,7 @@ PeriodTimer::~PeriodTimer ()
/** @param n Name to use when giving output.
* @param s Initial state.
*/
-StateTimer::StateTimer (string n, string s)
+StateDCPTimer::StateDCPTimer (string n, string s)
: _name (n)
{
struct timeval t;
@@ -59,7 +59,7 @@ StateTimer::StateTimer (string n, string s)
/** @param s New state that the caller is in */
void
-StateTimer::set_state (string s)
+StateDCPTimer::set_state (string s)
{
double const last = _time;
struct timeval t;
@@ -74,8 +74,8 @@ StateTimer::set_state (string s)
_state = s;
}
-/** Destroy StateTimer and generate a summary of the state timings on cout */
-StateTimer::~StateTimer ()
+/** Destroy StateDCPTimer and generate a summary of the state timings on cout */
+StateDCPTimer::~StateDCPTimer ()
{
if (_state.empty ()) {
return;